<?php
/**
 * Plugin Name: Tutor LMS Custom Fields
 * Description: A minimal plugin to add custom fields to Tutor LMS Course Builder.
 * Version: 1.0.0
 * Author: Tutor LMS
 *
 * @package TutorCustomFields
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


add_action( 'tutor_after_course_builder_load', 'tlcf_enqueue_scripts' );
add_action( 'save_post_courses', 'tlcf_save_course_meta' );
add_filter( 'tutor_course_details_response', 'tlcf_display_custom_field_data' );

/**
 * Display custom field data in course details
 *
 * @param array $data Course data array.
 *
 * @return array Modified course data array with custom field
 */
function tlcf_display_custom_field_data( array $data ) {
	$course_id   = $data['ID'];
	$seo_content = get_post_meta( $course_id, 'tlcf_seo_content', true );
	if ( $seo_content ) {
		$data['seo_content'] = $seo_content;
	}
	return $data;
}

/**
 * Save custom field data when course is saved
 *
 * @param int $post_id Course post ID.
 *
 * @return void
 */
function tlcf_save_course_meta( int $post_id ) {
	$seo_content = sanitize_text_field( wp_unslash( $_POST['seo_content'] ) ?? '' );
	if ( $seo_content ) {
		update_post_meta( $post_id, 'tlcf_seo_content', $seo_content );
	}
}

/**
 * Enqueue custom scripts for course builder
 *
 * @return void
 */
function tlcf_enqueue_scripts() {
	$js_url = plugin_dir_url( __FILE__ ) . 'custom-fields.js';
	wp_enqueue_script(
		'tlcf-custom-fields-js',
		$js_url,
		array( 'tutor-course-builder' ),
		'1.0.0',
		true
	);
}
